@@ -75,13 +75,20 @@ enum MDB_ASYNC_ST { // MariaDB Async State Machine
 	ASYNC_QUERY_START,
 	ASYNC_QUERY_CONT,
 	ASYNC_QUERY_END,
+	ASYNC_QUERY_SUCCESSFUL,
+	ASYNC_QUERY_FAILED,
+	ASYNC_QUERY_TIMEOUT,
 	ASYNC_NEXT_RESULT_START,
 	ASYNC_NEXT_RESULT_CONT,
 	ASYNC_NEXT_RESULT_END,
-#ifndef PROXYSQL_USE_RESULT
+//#ifndef PROXYSQL_USE_RESULT
 	ASYNC_STORE_RESULT_START,
 	ASYNC_STORE_RESULT_CONT,
-#endif // PROXYSQL_USE_RESULT
+	ASYNC_STORE_RESULT_END,
+	ASYNC_STORE_RESULT_SUCCESSFUL,
+	ASYNC_STORE_RESULT_FAILED,
+	ASYNC_STORE_RESULT_TIMEOUT,
+//#endif // PROXYSQL_USE_RESULT
 	ASYNC_USE_RESULT_START,
 	ASYNC_USE_RESULT_CONT,
 	ASYNC_INITDB_START,
@@ -104,6 +111,9 @@ enum MDB_ASYNC_ST { // MariaDB Async State Machine
 	ASYNC_STMT_EXECUTE_STORE_RESULT_START,
 	ASYNC_STMT_EXECUTE_STORE_RESULT_CONT,
 	ASYNC_STMT_EXECUTE_END,
+	ASYNC_CLOSE_START,
+	ASYNC_CLOSE_CONT,
+	ASYNC_CLOSE_END,
 
 	ASYNC_IDLE
 };
@@ -129,6 +139,7 @@ enum debug_module {
 	PROXY_DEBUG_QUERY_CACHE,
 	PROXY_DEBUG_QUERY_STATISTICS,
 	PROXY_DEBUG_RESTAPI,
+	PROXY_DEBUG_MONITOR,
 	PROXY_DEBUG_UNKNOWN // this module doesn't exist. It is used only to define the last possible module
 };
 
@@ -346,6 +357,7 @@ enum enum_mysql_command {
 	_MYSQL_COM_SET_OPTION = 27,
 	_MYSQL_COM_STMT_FETCH = 28,
 	_MYSQL_COM_DAEMON,
+	_MYSQL_COM_BINLOG_DUMP_GTID,
 	_MYSQL_COM_RESET_CONNECTION = 31,
 
   _MYSQL_COM_END
@@ -437,6 +449,7 @@ enum PROXYSQL_MYSQL_ERR {
 	ER_PROXYSQL_LAGGING_SRV                           = 9005,
 	ER_PROXYSQL_PING_TIMEOUT                          = 9006,
 	ER_PROXYSQL_CHANGE_USER_TIMEOUT                   = 9007,
+	ER_PROXYSQL_GR_HEALTH_CONN_CHECK_TIMEOUT          = 9020,
 	ER_PROXYSQL_GR_HEALTH_CHECK_TIMEOUT               = 9008,
 	ER_PROXYSQL_GR_HEALTH_CHECKS_MISSED               = 9009,
 	ER_PROXYSQL_READ_ONLY_CHECK_CONN_TIMEOUT          = 9010,
@@ -845,6 +858,7 @@ __thread int mysql_thread___client_host_error_counts;
 
 /* variables used for Query Cache */
 __thread int mysql_thread___query_cache_size_MB;
+__thread int mysql_thread___query_cache_soft_ttl_pct;
 
 /* variables used for SSL , from proxy to server (p2s) */
 __thread char * mysql_thread___ssl_p2s_ca;
@@ -1010,6 +1024,7 @@ extern __thread int mysql_thread___client_host_error_counts;
 
 /* variables used for Query Cache */
 extern __thread int mysql_thread___query_cache_size_MB;
+extern __thread int mysql_thread___query_cache_soft_ttl_pct;
 
 /* variables used for SSL , from proxy to server (p2s) */
 extern __thread char * mysql_thread___ssl_p2s_ca;
