@@ -1,7 +1,7 @@
 #include "MySQL_HostGroups_Manager.h"
 #include "proxysql.h"
 #include "cpp.h"
-#include "SpookyV2.h"
+//#include "SpookyV2.h"
 #include <fcntl.h>
 #include <sstream>
 
@@ -1115,6 +1115,7 @@ handler_again:
     	break;
 		case ASYNC_CONNECT_SUCCESSFUL:
 			if (mysql && ret_mysql) {
+				// PMC-10005
 				// we handle encryption for backend
 				//
 				// we have a similar code in MySQL_Data_Stream::attach_connection()
@@ -1981,6 +1982,14 @@ int MySQL_Connection::async_query(short event, char *stmt, unsigned long length,
 			return 0;
 			break;
 		case ASYNC_IDLE:
+			if (myds && myds->sess) {
+				if (myds->sess->active_transactions == 0) {
+					// every time we start a query (no matter if COM_QUERY, STMT_PREPARE or otherwise)
+					// also a transaction starts, even if in autocommit mode
+					myds->sess->active_transactions = 1;
+					myds->sess->transaction_started_at = myds->sess->thread->curtime;
+				}
+			}
 			if (stmt_meta==NULL)
 				set_query(stmt,length);
 			async_state_machine=ASYNC_QUERY_START;
@@ -2428,7 +2437,7 @@ bool MySQL_Connection::MultiplexDisabled(bool check_delay_token) {
 // status_flags stores information about the status of the connection
 // can be used to determine if multiplexing can be enabled or not
 	bool ret=false;
-	if (status_flags & (STATUS_MYSQL_CONNECTION_TRANSACTION|STATUS_MYSQL_CONNECTION_USER_VARIABLE|STATUS_MYSQL_CONNECTION_PREPARED_STATEMENT|STATUS_MYSQL_CONNECTION_LOCK_TABLES|STATUS_MYSQL_CONNECTION_TEMPORARY_TABLE|STATUS_MYSQL_CONNECTION_GET_LOCK|STATUS_MYSQL_CONNECTION_NO_MULTIPLEX|STATUS_MYSQL_CONNECTION_SQL_LOG_BIN0|STATUS_MYSQL_CONNECTION_FOUND_ROWS|STATUS_MYSQL_CONNECTION_HAS_SAVEPOINT) ) {
+	if (status_flags & (STATUS_MYSQL_CONNECTION_TRANSACTION|STATUS_MYSQL_CONNECTION_USER_VARIABLE|STATUS_MYSQL_CONNECTION_PREPARED_STATEMENT|STATUS_MYSQL_CONNECTION_LOCK_TABLES|STATUS_MYSQL_CONNECTION_TEMPORARY_TABLE|STATUS_MYSQL_CONNECTION_GET_LOCK|STATUS_MYSQL_CONNECTION_NO_MULTIPLEX|STATUS_MYSQL_CONNECTION_SQL_LOG_BIN0|STATUS_MYSQL_CONNECTION_FOUND_ROWS|STATUS_MYSQL_CONNECTION_NO_MULTIPLEX_HG|STATUS_MYSQL_CONNECTION_HAS_SAVEPOINT) ) {
 		ret=true;
 	}
 	if (check_delay_token && auto_increment_delay_token) return true;
@@ -2768,7 +2777,10 @@ int MySQL_Connection::async_send_simple_command(short event, char *stmt, unsigne
 }
 
 void MySQL_Connection::reset() {
+	bool old_no_multiplex_hg = get_status(STATUS_MYSQL_CONNECTION_NO_MULTIPLEX_HG);
 	status_flags=0;
+	// reconfigure STATUS_MYSQL_CONNECTION_NO_MULTIPLEX_HG
+	set_status(old_no_multiplex_hg,STATUS_MYSQL_CONNECTION_NO_MULTIPLEX_HG);
 	reusable=true;
 	options.last_set_autocommit=-1; // never sent
 
