@@ -23,8 +23,26 @@
 #include "proxysql_utils.h"
 
 using std::string;
+using std::vector;
 
-int show_variable(MYSQL *mysql, const std::string& var_name, std::string& var_value) {
+std::size_t count_matches(const string& str, const string& substr) {
+	std::size_t result = 0;
+	std::size_t pos = 0;
+
+	while ((pos = str.find(substr, pos)) != string::npos) {
+		result += 1;
+		pos += substr.length();
+	}
+
+	return result;
+}
+
+int mysql_query_t(MYSQL* mysql, const char* query) {
+	diag("%s: Issuing query '%s' to ('%s':%d)", get_formatted_time().c_str(), query, mysql->host, mysql->port);
+	return mysql_query(mysql, query);
+}
+
+int show_variable(MYSQL *mysql, const string& var_name, string& var_value) {
 	char query[128];
 
 	snprintf(query, sizeof(query),"show variables like '%s'", var_name.c_str());
@@ -46,7 +64,7 @@ int show_variable(MYSQL *mysql, const std::string& var_name, std::string& var_va
 	return 0;
 }
 
-int select_config_file(MYSQL* mysql, std::string& resultset) {
+int select_config_file(MYSQL* mysql, string& resultset) {
 	if (mysql_query(mysql, "select config file")) {
 	    fprintf(stderr, "File %s, line %d, Error: %s\n",
 	              __FILE__, __LINE__, mysql_error(mysql));
@@ -67,7 +85,7 @@ int select_config_file(MYSQL* mysql, std::string& resultset) {
 	return 0;
 }
 
-int show_admin_global_variable(MYSQL *mysql, const std::string& var_name, std::string& var_value) {
+int show_admin_global_variable(MYSQL *mysql, const string& var_name, string& var_value) {
 	char query[128];
 
 	snprintf(query, sizeof(query),"select variable_value from global_variables where variable_name='%s'", var_name.c_str());
@@ -89,7 +107,7 @@ int show_admin_global_variable(MYSQL *mysql, const std::string& var_name, std::s
 	return 0;
 }
 
-int set_admin_global_variable(MYSQL *mysql, const std::string& var_name, const std::string& var_value) {
+int set_admin_global_variable(MYSQL *mysql, const string& var_name, const string& var_value) {
 	char query[128];
 
 	snprintf(query, sizeof(query),"update global_variables set variable_value = '%s' where variable_name='%s'", var_value.c_str(), var_name.c_str());
@@ -102,7 +120,7 @@ int set_admin_global_variable(MYSQL *mysql, const std::string& var_name, const s
 }
 
 
-int get_server_version(MYSQL *mysql, std::string& version) {
+int get_server_version(MYSQL *mysql, string& version) {
 	char query[128];
 
 	if (mysql_query(mysql, "select @@version")) {
@@ -171,6 +189,7 @@ int add_more_rows_test_sbtest1(int num_rows, MYSQL *mysql, bool sqlite) {
 	diag("Done!");
 	return 0;
 }
+
 int create_table_test_sbtest1(int num_rows, MYSQL *mysql) {
 	MYSQL_QUERY(mysql, "CREATE DATABASE IF NOT EXISTS test");
 	MYSQL_QUERY(mysql, "DROP TABLE IF EXISTS test.sbtest1");
@@ -187,7 +206,7 @@ int create_table_test_sqlite_sbtest1(int num_rows, MYSQL *mysql) {
 	return add_more_rows_test_sbtest1(num_rows, mysql, true);
 }
 
-int execvp(const std::string& cmd, const std::vector<const char*>& argv, std::string& result) {
+int execvp(const string& cmd, const std::vector<const char*>& argv, string& result) {
 	// Pipes definition
 	constexpr uint8_t NUM_PIPES = 3;
 	constexpr uint8_t PARENT_WRITE_PIPE = 0;
@@ -207,7 +226,7 @@ int execvp(const std::string& cmd, const std::vector<const char*>& argv, std::st
 	const auto& CHILD_WRITE_ERR = pipes[PARENT_ERR_PIPE][WRITE_FD];
 
 	int err = 0;
-	std::string result_ = "";
+	string result_ = "";
 	std::vector<const char*> _argv = argv;
 
 	// Append null to end of _argv for extra safety
@@ -277,9 +296,9 @@ int execvp(const std::string& cmd, const std::vector<const char*>& argv, std::st
 	return err;
 }
 
-int exec(const std::string& cmd, std::string& result) {
+int exec(const string& cmd, string& result) {
 	char buffer[128];
-	std::string result_ = "";
+	string result_ = "";
 	int err = 0;
 
 	// Try to invoke the shell
@@ -317,7 +336,7 @@ std::vector<mysql_res_row> extract_mysql_rows(MYSQL_RES* my_res) {
 		uint64_t *lengths = mysql_fetch_lengths(my_res);
 
 		for (uint32_t i = 0; i < num_fields; i++) {
-			std::string field_val(row[i], lengths[i]);
+			string field_val(row[i], lengths[i]);
 			row_values.push_back(field_val);
 		}
 
@@ -350,8 +369,7 @@ static size_t write_callback(void *data, size_t size, size_t nmemb, void *userp)
 }
 
 CURLcode perform_simple_post(
-	const std::string& endpoint, const std::string& post_params,
-	uint64_t& curl_res_code, std::string& curl_out_err
+	const string& endpoint, const string& params, uint64_t& curl_res_code, string& curl_res_data
 ) {
 	CURL *curl;
 	CURLcode res;
@@ -361,7 +379,7 @@ CURLcode perform_simple_post(
 	curl = curl_easy_init();
 	if(curl) {
 		curl_easy_setopt(curl, CURLOPT_URL, endpoint.c_str());
-		curl_easy_setopt(curl, CURLOPT_POSTFIELDS, post_params.c_str());
+		curl_easy_setopt(curl, CURLOPT_POSTFIELDS, params.c_str());
 		struct memory response = { 0 };
 		curl_easy_setopt(curl, CURLOPT_WRITEFUNCTION, write_callback);
 		curl_easy_setopt(curl, CURLOPT_WRITEDATA, (void *)&response);
@@ -369,38 +387,62 @@ CURLcode perform_simple_post(
 		res = curl_easy_perform(curl);
 
 		if(res != CURLE_OK) {
-			curl_out_err = std::string { curl_easy_strerror(res) };
+			curl_res_data = string { curl_easy_strerror(res) };
 		} else {
 			curl_easy_getinfo(curl, CURLINFO_RESPONSE_CODE, &curl_res_code);
-
-			if (curl_res_code != 200) {
-				curl_out_err = string(response.data, response.size);
-			}
+			curl_res_data = string(response.data, response.size);
 		}
 
+		free(response.data);
 		curl_easy_cleanup(curl);
 	}
 
 	return res;
 }
 
-int wait_until_enpoint_ready(
-	std::string endpoint, std::string post_params, uint32_t timeout, uint32_t delay
+CURLcode perform_simple_get(
+	const string& endpoint, uint64_t& curl_res_code, string& curl_res_data
 ) {
+	CURL *curl;
+	CURLcode res;
+
+	curl_global_init(CURL_GLOBAL_ALL);
+
+	curl = curl_easy_init();
+	if(curl) {
+		curl_easy_setopt(curl, CURLOPT_URL, endpoint.c_str());
+		struct memory response = { 0 };
+		curl_easy_setopt(curl, CURLOPT_WRITEFUNCTION, write_callback);
+		curl_easy_setopt(curl, CURLOPT_WRITEDATA, (void *)&response);
+
+		res = curl_easy_perform(curl);
+
+		if(res != CURLE_OK) {
+			curl_res_data = string { curl_easy_strerror(res) };
+		} else {
+			curl_easy_getinfo(curl, CURLINFO_RESPONSE_CODE, &curl_res_code);
+			curl_res_data = string(response.data, response.size);
+		}
+
+		free(response.data);
+		curl_easy_cleanup(curl);
+	}
+
+	return res;
+}
+
+int wait_post_enpoint_ready(string endpoint, string post_params, uint32_t timeout, uint32_t delay) {
 	double waited = 0;
 	int res = -1;
 
 	while (waited < timeout) {
-		std::string curl_str_err {};
+		string curl_resp_err {};
 		uint64_t curl_res_code = 0;
-		int curl_err = perform_simple_post(endpoint, post_params, curl_res_code, curl_str_err);
+		int curl_res = perform_simple_post(endpoint, post_params, curl_res_code, curl_resp_err);
 
-		if (curl_err != CURLE_OK) {
-			diag(
-				"'curl_err_code': %d, 'curl_err': '%s', waiting for '%d'ms...",
-				curl_err, curl_str_err.c_str(), delay
-			);
-			waited += static_cast<double>(delay) / 1000;
+		if (curl_res != CURLE_OK || curl_res_code != 200) {
+			diag("'curl_res': %d, 'curl_err': '%s', waiting for '%d'ms...", curl_res, curl_resp_err.c_str(), delay);
+			waited += static_cast<double>(delay);
 			usleep(delay * 1000);
 		} else {
 			res = 0;
@@ -411,8 +453,30 @@ int wait_until_enpoint_ready(
 	return res;
 }
 
-std::string random_string(std::size_t strSize) {
-	std::string dic { "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz" };
+int wait_get_enpoint_ready(string endpoint, uint32_t timeout, uint32_t delay) {
+	double waited = 0;
+	int res = -1;
+
+	while (waited < timeout) {
+		string curl_resp_err {};
+		uint64_t curl_res_code = 0;
+		int curl_res = perform_simple_get(endpoint, curl_res_code, curl_resp_err);
+
+		if (curl_res != CURLE_OK || curl_res_code != 200) {
+			diag("'curl_res': %d, 'curl_err': '%s', waiting for '%d'ms...", curl_res, curl_resp_err.c_str(), delay);
+			waited += static_cast<double>(delay);
+			usleep(delay * 1000);
+		} else {
+			res = 0;
+			break;
+		}
+	}
+
+	return res;
+}
+
+string random_string(std::size_t strSize) {
+	string dic { "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz" };
 
 	std::random_device rd {};
 	std::mt19937 generator { rd() };
@@ -424,7 +488,7 @@ std::string random_string(std::size_t strSize) {
 	} else {
 		std::size_t req_modulus = static_cast<std::size_t>(strSize / dic.size());
 		std::size_t req_reminder = strSize % dic.size();
-		std::string random_str {};
+		string random_str {};
 
 		for (std::size_t i = 0; i < req_modulus; i++) {
 			random_str.append(dic);
@@ -439,20 +503,20 @@ std::string random_string(std::size_t strSize) {
 const double COLISSION_PROB = 1e-8;
 
 int wait_for_replication(
-	MYSQL* proxy, MYSQL* proxy_admin, const std::string& check, uint32_t timeout, uint32_t read_hg
+	MYSQL* proxy, MYSQL* proxy_admin, const string& check, uint32_t timeout, uint32_t read_hg
 ) {
 	if (proxy == NULL) { return EXIT_FAILURE; }
 
-	const std::string t_count_reader_hg_servers {
+	const string t_count_reader_hg_servers {
 		"SELECT COUNT(*) FROM mysql_servers WHERE hostgroup_id=%d"
 	};
-	std::string count_reader_hg_servers {};
+	string count_reader_hg_servers {};
 	size_t size =
 		snprintf( nullptr, 0, t_count_reader_hg_servers.c_str(), read_hg) + 1;
 	{
 		std::unique_ptr<char[]> buf(new char[size]);
 		snprintf(buf.get(), size, t_count_reader_hg_servers.c_str(), read_hg);
-		count_reader_hg_servers = std::string(buf.get(), buf.get() + size - 1);
+		count_reader_hg_servers = string(buf.get(), buf.get() + size - 1);
 	}
 
 	MYSQL_QUERY(proxy_admin, count_reader_hg_servers.c_str());
@@ -487,7 +551,7 @@ int wait_for_replication(
 					if (field_num == 1 && row_num == 1) {
 						MYSQL_ROW row = mysql_fetch_row(st_res);
 
-						std::string exp_res { "TRUE" };
+						string exp_res { "TRUE" };
 						if (strcasecmp(exp_res.c_str(), row[0]) == 0) {
 							correct_result = true;
 							queries += 1;
@@ -538,19 +602,19 @@ MARIADB_CHARSET_INFO * proxysql_find_charset_collate(const char *collatename) {
 
 int create_proxysql_user(
 	MYSQL* proxysql_admin,
-	const std::string& user,
-	const std::string& pass,
-	const std::string& attributes
+	const string& user,
+	const string& pass,
+	const string& attributes
 ) {
-	std::string t_del_user_query { "DELETE FROM mysql_users WHERE username='%s'" };
-	std::string del_user_query {};
+	string t_del_user_query { "DELETE FROM mysql_users WHERE username='%s'" };
+	string del_user_query {};
 	string_format(t_del_user_query, del_user_query, user.c_str());
 
-	std::string t_insert_user {
+	string t_insert_user {
 		"INSERT INTO mysql_users (username,password,active,attributes)"
 		" VALUES ('%s','%s',1,'%s')"
 	};
-	std::string insert_user {};
+	string insert_user {};
 	string_format(t_insert_user, insert_user, user.c_str(), pass.c_str(), attributes.c_str());
 
 	MYSQL_QUERY(proxysql_admin, del_user_query.c_str());
@@ -561,21 +625,21 @@ int create_proxysql_user(
 
 int create_mysql_user(
 	MYSQL* mysql_server,
-	const std::string& user,
-	const std::string& pass
+	const string& user,
+	const string& pass
 ) {
-	const std::string t_drop_user_query { "DROP USER IF EXISTS %s@'%%'" };
-	std::string drop_user_query {};
+	const string t_drop_user_query { "DROP USER IF EXISTS %s@'%%'" };
+	string drop_user_query {};
 	string_format(t_drop_user_query, drop_user_query, user.c_str());
 
-	const std::string t_create_user_query {
+	const string t_create_user_query {
 		"CREATE USER IF NOT EXISTS %s@'%%' IDENTIFIED WITH 'mysql_native_password' BY \"%s\""
 	};
-	std::string create_user_query {};
+	string create_user_query {};
 	string_format(t_create_user_query, create_user_query, user.c_str(), pass.c_str());
 
-	const std::string t_grant_all_query { "GRANT ALL ON *.* TO %s@'%%'" };
-	std::string grant_all_query { };
+	const string t_grant_all_query { "GRANT ALL ON *.* TO %s@'%%'" };
+	string grant_all_query { };
 	string_format(t_grant_all_query, grant_all_query, user.c_str());
 
 	MYSQL_QUERY(mysql_server, drop_user_query.c_str());
@@ -590,13 +654,13 @@ int create_extra_users(
 	MYSQL* mysql_server,
 	const std::vector<user_config>& users_config
 ) {
-	std::vector<std::pair<std::string, std::string>> v_user_pass {};
+	std::vector<std::pair<string, string>> v_user_pass {};
 	std::transform(
 		std::begin(users_config),
 		std::end(users_config),
 		std::back_inserter(v_user_pass),
 		[](const user_config& u_config) {
-			return std::pair<std::string, std::string> {
+			return std::pair<string, string> {
 				std::get<0>(u_config),
 				std::get<1>(u_config)
 			};
@@ -629,14 +693,14 @@ int create_extra_users(
 	return EXIT_SUCCESS;
 }
 
-std::string tap_curtime() {
+string tap_curtime() {
 	time_t __timer;
 	char lut[30];
 	struct tm __tm_info;
 	time(&__timer);
 	localtime_r(&__timer, &__tm_info);
 	strftime(lut, 25, "%Y-%m-%d %H:%M:%S", &__tm_info);
-	std::string s = std::string(lut);
+	string s = string(lut);
 	return s;
 }
 
@@ -649,7 +713,7 @@ int get_proxysql_cpu_usage(const CommandLine& cl, uint32_t intv, uint32_t& cpu_u
 	}
 
 	// recover admin variables
-	std::string set_stats_query { "SET admin-stats_system_cpu=" + std::to_string(intv) };
+	string set_stats_query { "SET admin-stats_system_cpu=" + std::to_string(intv) };
 	MYSQL_QUERY(proxysql_admin, set_stats_query.c_str());
 	MYSQL_QUERY(proxysql_admin, "LOAD ADMIN VARIABLES TO RUNTIME");
 
@@ -706,7 +770,7 @@ MYSQL* wait_for_proxysql(const conn_opts_t& opts, int timeout) {
 }
 
 int get_variable_value(
-	MYSQL* proxysql_admin, const std::string& variable_name, std::string& variable_value, bool runtime
+	MYSQL* proxysql_admin, const string& variable_name, string& variable_value, bool runtime
 ) {
 	if (proxysql_admin == NULL) {
 		return EINVAL;
@@ -714,10 +778,10 @@ int get_variable_value(
 
 	int res = EXIT_FAILURE;
 
-	const std::string t_select_var_query {
+	const string t_select_var_query {
 		"SELECT * FROM %sglobal_variables WHERE Variable_name='%s'"
 	};
-	std::string select_var_query {};
+	string select_var_query {};
 
 	if (runtime) {
 		string_format(t_select_var_query, select_var_query, "runtime_", variable_name.c_str());
@@ -742,7 +806,7 @@ int get_variable_value(
 		}
 
 		// Extract the result
-		std::string _variable_value { row[1] };
+		string _variable_value { row[1] };
 		variable_value = _variable_value;
 
 		res = EXIT_SUCCESS;
@@ -754,3 +818,254 @@ cleanup:
 
 	return res;
 }
+
+string to_string(const conn_cnf_t& cnf) {
+	return string {
+		string { "{" }
+			+ "\"enable_client_deprecate_eof\":" + std::to_string(cnf.f_conn_eof) + ","
+			+ "\"enable_server_deprecate_eof\":" + std::to_string(cnf.b_conn_eof) + ","
+			+ "\"client_compression\":" + std::to_string(cnf.f_conn_compr) + ","
+			+ "\"server_compression\":" + std::to_string(cnf.b_conn_compr) + ","
+			+ "\"fast_forward\":" + std::to_string(cnf.fast_forward) + ","
+			+ "\"fast_forward_user\":''" + cnf.fast_forward_user + "'"
+		"}"
+	};
+}
+
+int execute_eof_test(
+	const CommandLine& cl, MYSQL* mysql, const string& test, bool cl_depr_eof, bool srv_depr_eof
+) {
+	if (!mysql) { return -1; }
+
+	string q_client_deprecate_eof { "SET mysql-enable_client_deprecate_eof='" + std::to_string(cl_depr_eof) + "'" };
+	string q_server_deprecate_eof { "SET mysql-enable_server_deprecate_eof='" + std::to_string(srv_depr_eof) + "'" };
+
+	MYSQL_QUERY(mysql, q_client_deprecate_eof.c_str() );
+	MYSQL_QUERY(mysql, q_server_deprecate_eof.c_str() );
+
+	MYSQL_QUERY(mysql, "LOAD MYSQL VARIABLES TO RUNTIME");
+
+	int cache_res = system(string { string(cl.workdir) + test }.c_str());
+	ok(
+		cache_res == 0,
+		"'%s' succeed with ('mysql-enable_client_deprecate_eof': '%d', 'mysql-enable_server_deprecate_eof': '%d')",
+		test.c_str(),
+		cl_depr_eof,
+		srv_depr_eof
+	);
+
+	return cache_res;
+}
+
+int execute_eof_test(const CommandLine& cl, MYSQL* mysql, const string& test, const conn_cnf_t& conn_cnf) {
+	if (!mysql) { return -1; }
+
+	int test_res = 0;
+
+	// Set 'DEPRECATE_EOF' flags
+	string q_client_deprecate_eof { "SET mysql-enable_client_deprecate_eof='" + std::to_string(conn_cnf.f_conn_eof) + "'" };
+	string q_server_deprecate_eof { "SET mysql-enable_server_deprecate_eof='" + std::to_string(conn_cnf.b_conn_eof) + "'" };
+
+	MYSQL_QUERY_T(mysql, q_client_deprecate_eof.c_str() );
+	MYSQL_QUERY_T(mysql, q_server_deprecate_eof.c_str() );
+
+	MYSQL_QUERY_T(mysql, "LOAD MYSQL VARIABLES TO RUNTIME");
+
+	// Set server 'compression' flags
+	string q_server_compr { "UPDATE mysql_servers SET compression=" + std::to_string(conn_cnf.b_conn_compr) };
+	// Set client connection flags enabling compression
+	if (conn_cnf.f_conn_compr) {
+		setenv("TAP_CLIENT_FLAGS", "32", 1);
+	} else {
+		setenv("TAP_CLIENT_FLAGS", "0", 1);
+	}
+
+	MYSQL_QUERY_T(mysql, "LOAD MYSQL SERVERS TO RUNTIME");
+
+	// Backup current username before changing it for the next test
+	const char* pre_tap_user = getenv("TAP_USERNAME");
+	if (conn_cnf.fast_forward_user.empty() == false) {
+		setenv("TAP_USERNAME", conn_cnf.fast_forward_user.c_str(), 1);
+	}
+	// Config assumes same name and password for the test user
+	const char* pre_tap_pass = getenv("TAP_PASSWORD");
+	if (conn_cnf.fast_forward_user.empty() == false) {
+		setenv("TAP_PASSWORD", conn_cnf.fast_forward_user.c_str(), 1);
+	}
+
+	// Set 'fast-forward' for target connecting user
+	const string ff_str { std::to_string(conn_cnf.fast_forward) };
+	const string ff_user { conn_cnf.fast_forward_user };
+	const string q_ff_user {
+		"UPDATE mysql_users SET fast_forward=" + ff_str + " WHERE username='" + ff_user + "'"
+	};
+
+	int rc = mysql_query_t(mysql, q_ff_user.c_str());
+
+	if (rc) {
+		diag("Query '%s' failed with error '%s'", q_ff_user.c_str(), mysql_error(mysql));
+		goto cleanup;
+	}
+
+	{
+		rc = mysql_query_t(mysql, "LOAD MYSQL USERS TO RUNTIME");
+		if (rc) {
+			diag("Query '%s' failed with error '%s'", q_ff_user.c_str(), mysql_error(mysql));
+			goto cleanup;
+		}
+
+		test_res = system(string { string(cl.workdir) + test }.c_str());
+		ok(test_res == 0, "'%s' should succeed with config '%s'", test.c_str(), to_string(conn_cnf).c_str());
+	}
+
+cleanup:
+
+	// Recover previous 'TAP_USERNAME' env variable
+	if (pre_tap_user) {
+		setenv("TAP_USERNAME", pre_tap_user, 1);
+	}
+	if (pre_tap_user) {
+		setenv("TAP_PASSWORD", pre_tap_pass, 1);
+	}
+
+	return test_res;
+}
+
+int get_cur_backend_conns(MYSQL* proxy_admin, const string& conn_type, uint32_t& found_conn_num) {
+	MYSQL_QUERY(proxy_admin, string {"SELECT " + conn_type + " FROM stats_mysql_connection_pool"}.c_str());
+
+	MYSQL_ROW row = nullptr;
+	MYSQL_RES* my_res = mysql_store_result(proxy_admin);
+	uint32_t field_num = mysql_num_fields(my_res);
+	vector<uint32_t> connfree_vals {};
+
+	if (field_num != 1) {
+		diag("Invalid number of columns in resulset from 'stats_mysql_connection_pool': %d", field_num);
+	}
+
+	if (my_res != nullptr) {
+		while ((row = mysql_fetch_row(my_res))) {
+			connfree_vals.push_back(std::strtol(row[0], NULL, 10));
+		}
+	}
+	mysql_free_result(my_res);
+
+	found_conn_num = std::accumulate(connfree_vals.begin(), connfree_vals.end(), 0, std::plus<uint32_t>());
+	return EXIT_SUCCESS;
+}
+
+int wait_for_backend_conns(
+	MYSQL* proxy_admin, const string& conn_type, uint32_t exp_conn_num, uint32_t timeout
+) {
+	uint32_t total_conn_num = 0;
+	uint32_t waited = 0;
+
+	while (waited < timeout) {
+		int get_err = get_cur_backend_conns(proxy_admin, conn_type, total_conn_num);
+		if (get_err != EXIT_SUCCESS) { return EXIT_FAILURE; }
+
+		if (total_conn_num == exp_conn_num) {
+			break;
+		} else {
+			sleep(1);
+			waited += 1;
+		}
+	}
+
+	if (waited >= timeout) {
+		return EXIT_FAILURE;
+	} else {
+		return EXIT_SUCCESS;
+	}
+}
+
+string join_path(const string& p1, const string& p2) {
+	if (p1.back() == '/') {
+		return p1 + p2;
+	} else {
+		return p1 + '/' + p2;
+	}
+}
+
+int check_endpoint_exists(MYSQL* admin, const ept_info_t& ept, bool& exists) {
+	const string select_query {
+		"SELECT count(*) FROM restapi_routes WHERE uri='" + ept.name + "' AND method='" + ept.method + "'"
+	};
+	MYSQL_QUERY(admin, select_query.c_str());
+	MYSQL_RES* myres = mysql_store_result(admin);
+	MYSQL_ROW myrow = mysql_fetch_row(myres);
+	bool res = EXIT_FAILURE;
+
+	if (myrow && myrow[0]) {
+		int entry_num = std::atoi(myrow[0]);
+		exists = entry_num != 0;
+
+		res = EXIT_SUCCESS;
+	} else {
+		diag("Invalid resultset returned from query '%s'", select_query.c_str());
+
+		res = EXIT_FAILURE;
+	}
+
+	mysql_free_result(myres);
+
+	return res;
+}
+
+const char t_restapi_insert[] {
+	"INSERT INTO restapi_routes (active, timeout_ms, method, uri, script, comment) "
+		"VALUES (1,%ld,'%s','%s','%s','comm')",
+};
+
+const string base_address { "http://localhost:6070/sync/" };
+
+int configure_endpoints(
+	MYSQL* admin,
+	const string& script_base_path,
+	const vector<ept_info_t>& epts_info,
+	const ept_info_t& dummy_ept,
+	bool prevent_dups
+) {
+	MYSQL_QUERY(admin, "DELETE FROM restapi_routes");
+
+	vector<ept_info_t> _epts_info { epts_info };
+	_epts_info.push_back(dummy_ept);
+
+	for (const ept_info_t& ept : _epts_info) {
+		string f_exe_name {};
+		string_format(ept.file, f_exe_name, ept.name.c_str());
+
+		const string script_path { join_path(script_base_path, f_exe_name) };
+		string insert_query {};
+		string_format(
+			t_restapi_insert, insert_query, ept.timeout, ept.method.c_str(), ept.name.c_str(), script_path.c_str()
+		);
+
+		bool duplicate_entry = false;
+		if (check_endpoint_exists(admin, ept, duplicate_entry)) {
+			return EXIT_FAILURE;
+		}
+
+		if (!(prevent_dups && duplicate_entry)) {
+			MYSQL_QUERY(admin, insert_query.c_str());
+		} else {
+			diag(
+				"Warning: Test payload trying to insert invalid duplicated entry - uri: '%s', method: '%s'",
+				ept.name.c_str(), ept.method.c_str()
+			);
+			exit(EXIT_FAILURE);
+		}
+	}
+
+	MYSQL_QUERY(admin, "LOAD RESTAPI TO RUNTIME");
+
+	const string full_endpoint { join_path(base_address, dummy_ept.name) };
+	int endpoint_timeout = wait_post_enpoint_ready(full_endpoint, "{}", 1000, 100);
+
+	if (endpoint_timeout) {
+		diag("Timeout while trying to reach first valid enpoint");
+		return EXIT_FAILURE;
+	}
+
+	return EXIT_SUCCESS;
+}
